Coverage report

File | class |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src / crump / __init__.py | (no class) |  | 5 | 0 | 0 |  | 100%
src / crump / cdf_extractor.py | (no class) |  | 260 | 35 | 0 |  | 87%
src / crump / cdf_reader.py | CDFVariable |  | 58 | 14 | 0 |  | 76%
src / crump / cdf_reader.py | (no class) |  | 76 | 18 | 0 |  | 76%
src / crump / cli.py | (no class) |  | 15 | 0 | 0 |  | 100%
src / crump / cli_extract.py | (no class) |  | 168 | 24 | 0 |  | 86%
src / crump / cli_inspect.py | (no class) |  | 210 | 38 | 0 |  | 82%
src / crump / cli_prepare.py | (no class) |  | 214 | 17 | 0 |  | 92%
src / crump / cli_sync.py | (no class) |  | 140 | 35 | 0 |  | 75%
src / crump / config.py | ColumnMapping |  | 46 | 7 | 0 |  | 85%
src / crump / config.py | FilenameColumnMapping |  | 4 | 0 | 0 |  | 100%
src / crump / config.py | FilenameToColumn |  | 18 | 1 | 0 |  | 94%
src / crump / config.py | IndexColumn |  | 4 | 0 | 0 |  | 100%
src / crump / config.py | Index |  | 4 | 0 | 0 |  | 100%
src / crump / config.py | CrumpJob |  | 11 | 1 | 0 |  | 91%
src / crump / config.py | CrumpConfig |  | 243 | 28 | 0 |  | 88%
src / crump / config.py | (no class) |  | 71 | 1 | 0 |  | 99%
src / crump / console_utils.py | (no class) |  | 8 | 1 | 0 |  | 88%
src / crump / csv_file.py | CsvFileReader |  | 18 | 1 | 0 |  | 94%
src / crump / csv_file.py | CsvFileWriter |  | 15 | 0 | 0 |  | 100%
src / crump / csv_file.py | (no class) |  | 18 | 0 | 0 |  | 100%
src / crump / database.py | DryRunSummary |  | 6 | 0 | 0 |  | 100%
src / crump / database.py | DatabaseBackend |  | 14 | 14 | 0 |  | 0%
src / crump / database.py | PostgreSQLBackend |  | 91 | 3 | 0 |  | 97%
src / crump / database.py | SQLiteBackend |  | 102 | 5 | 0 |  | 95%
src / crump / database.py | DatabaseConnection |  | 314 | 31 | 0 |  | 90%
src / crump / database.py | (no class) |  | 115 | 2 | 0 |  | 98%
src / crump / file_types.py | OutputFileType |  | 8 | 0 | 0 |  | 100%
src / crump / file_types.py | InputFileType |  | 12 | 1 | 0 |  | 92%
src / crump / file_types.py | (no class) |  | 17 | 0 | 0 |  | 100%
src / crump / history.py | SyncHistoryEntry |  | 10 | 0 | 0 |  | 100%
src / crump / history.py | (no class) |  | 27 | 0 | 2 |  | 100%
src / crump / parquet_file.py | ParquetFileReader |  | 14 | 1 | 0 |  | 93%
src / crump / parquet_file.py | ParquetFileWriter |  | 42 | 2 | 0 |  | 95%
src / crump / parquet_file.py | (no class) |  | 23 | 2 | 0 |  | 91%
src / crump / tabular_file.py | TabularFileReader |  | 5 | 4 | 0 |  | 20%
src / crump / tabular_file.py | TabularFileWriter |  | 5 | 3 | 0 |  | 40%
src / crump / tabular_file.py | (no class) |  | 66 | 13 | 0 |  | 80%
src / crump / type_detection.py | (no class) |  | 100 | 2 | 0 |  | 98%
Total |  |  | 2577 | 304 | 2 |  | 88%

No items found using the specified filter.

3 empty classes skipped.